elephant.test.test_kernels module — Elephant 0.5.0 documentation

# elephant.test.test_kernels module

Unit tests for the kernels module.

class `elephant.test.test_kernels.` `kernel_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_error_alpha_kernel`(*args, **kwargs)
  `test_error_kernels`()

    Test of various error cases in the kernels module.

  `test_kernel_boundary_enclosing`()

    Test whether the integral of the kernel with boundary taken from the return value of the method boundary_enclosing_area_fraction is (almost) equal to the input variable fraction of boundary_enclosing_area_fraction.

  `test_kernels_normalization`()

    Test that each kernel normalizes to area one.

  `test_kernels_stddev`()

    Test that the standard deviation calculated from the kernel (almost) equals the parameter sigma with which the kernel was constructed.